package com.zyc.system.mapper;

import java.util.List;
import com.zyc.system.domain.VpnServices;

/**
 * 虚拟专用网络VPN服务Mapper接口
 * 
 * @author zyc
 * @date 2024-12-26
 */
public interface VpnServicesMapper 
{
    /**
     * 查询虚拟专用网络VPN服务
     * 
     * @param id 虚拟专用网络VPN服务主键
     * @return 虚拟专用网络VPN服务
     */
    public VpnServices selectVpnServicesById(Integer id);

    /**
     * 查询虚拟专用网络VPN服务列表
     * 
     * @param vpnServices 虚拟专用网络VPN服务
     * @return 虚拟专用网络VPN服务集合
     */
    public List<VpnServices> selectVpnServicesList(VpnServices vpnServices);

    /**
     * 新增虚拟专用网络VPN服务
     * 
     * @param vpnServices 虚拟专用网络VPN服务
     * @return 结果
     */
    public int insertVpnServices(VpnServices vpnServices);

    /**
     * 修改虚拟专用网络VPN服务
     * 
     * @param vpnServices 虚拟专用网络VPN服务
     * @return 结果
     */
    public int updateVpnServices(VpnServices vpnServices);

    /**
     * 删除虚拟专用网络VPN服务
     * 
     * @param id 虚拟专用网络VPN服务主键
     * @return 结果
     */
    public int deleteVpnServicesById(Integer id);

    /**
     * 批量删除虚拟专用网络VPN服务
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteVpnServicesByIds(Integer[] ids);
}
