package com.zyc.web.controller.api;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.zyc.common.annotation.Log;
import com.zyc.common.core.controller.BaseController;
import com.zyc.common.core.domain.AjaxResult;
import com.zyc.common.enums.BusinessType;
import com.zyc.system.domain.VpnServices;
import com.zyc.system.service.IVpnServicesService;
import com.zyc.common.utils.poi.ExcelUtil;
import com.zyc.common.core.page.TableDataInfo;

/**
 * 虚拟专用网络VPN服务Controller
 * 
 * @author zyc
 * @date 2024-12-26
 */
@RestController
@RequestMapping("/system/VpnServicesController")
public class VpnServicesController extends BaseController
{
    @Autowired
    private IVpnServicesService vpnServicesService;

    /**
     * 查询虚拟专用网络VPN服务列表
     */
    @PreAuthorize("@ss.hasPermi('system:services:list')")
    @GetMapping("/list")
    public TableDataInfo list(VpnServices vpnServices)
    {
        startPage();
        List<VpnServices> list = vpnServicesService.selectVpnServicesList(vpnServices);
        return getDataTable(list);
    }

    /**
     * 导出虚拟专用网络VPN服务列表
     */
    @PreAuthorize("@ss.hasPermi('system:services:export')")
    @Log(title = "虚拟专用网络VPN服务", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, VpnServices vpnServices)
    {
        List<VpnServices> list = vpnServicesService.selectVpnServicesList(vpnServices);
        ExcelUtil<VpnServices> util = new ExcelUtil<VpnServices>(VpnServices.class);
        util.exportExcel(response, list, "虚拟专用网络VPN服务数据");
    }

    /**
     * 获取虚拟专用网络VPN服务详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:services:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Integer id)
    {
        return success(vpnServicesService.selectVpnServicesById(id));
    }

    /**
     * 新增虚拟专用网络VPN服务
     */
    @PreAuthorize("@ss.hasPermi('system:services:add')")
    @Log(title = "虚拟专用网络VPN服务", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody VpnServices vpnServices)
    {
        return toAjax(vpnServicesService.insertVpnServices(vpnServices));
    }

    /**
     * 修改虚拟专用网络VPN服务
     */
    @PreAuthorize("@ss.hasPermi('system:services:edit')")
    @Log(title = "虚拟专用网络VPN服务", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody VpnServices vpnServices)
    {
        return toAjax(vpnServicesService.updateVpnServices(vpnServices));
    }

    /**
     * 删除虚拟专用网络VPN服务
     */
    @PreAuthorize("@ss.hasPermi('system:services:remove')")
    @Log(title = "虚拟专用网络VPN服务", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Integer[] ids)
    {
        return toAjax(vpnServicesService.deleteVpnServicesByIds(ids));
    }
}
